#
# spec file for package audacity
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with mad
%bcond_with lame
%bcond_with twolame
Name:           audacity
Version:        2.1.2
Release:        0
Summary:        A Free, Cross-Platform Digital Audio Editor
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Editors and Convertors
Url:            http://audacityteam.org/
Source:         %{name}-minsrc-%{version}.tar.xz
Source1:        %{name}-license-nyquist
Source2:        %{name}-rpmlintrc
# PATCH-FIX-OPENSUSE audacity-no_buildstamp.patch reddwarf@opensuse.org -- Remove the buildstamp.
Patch0:         %{name}-no_buildstamp.patch
# PATCH-FIX-OPENSUSE audacity-flac_assert.h.patch joerg.lorenzen@ki.tng.de -- Patch to fix build against libflac 1.3.0+.
Patch1:         %{name}-flac_assert.h.patch
# PATCH-FIX-UPSTREAM audacity-fix-nonsense.patch sor.alexei@meowr.ru -- Remove things that break build for no reason.
Patch2:         %{name}-fix-nonsense.patch
# PATCH-FIX-UPSTREAM audacity-ffmpeg.patch reddwarf@opensuse.org -- Patch to compile with latest ffmpeg.
Patch3:         %{name}-ffmpeg.patch
# PATCH-FIX-UPSTREAM audacity-gcc6.patch mliska@suse.cz -- Fix GCC6 warnings.
Patch5:         %{name}-gcc6.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  wxWidgets-3_0-nostl-devel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(flac++)
BuildRequires:  pkgconfig(gtk+-2.0) >= 2.4.0
BuildRequires:  pkgconfig(id3tag)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libavcodec) >= 51.53
BuildRequires:  pkgconfig(libavformat) >= 52.12
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(shared-mime-info)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(soundtouch)
BuildRequires:  pkgconfig(soxr)
BuildRequires:  pkgconfig(vamp-hostsdk)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vorbisenc)
BuildRequires:  pkgconfig(vorbisfile)
# This would require to patch our portaudio package with "PortMixer"... an extra API that never got integrated in PortAudio.
#BuildRequires:  portaudio-devel
Recommends:     %{name}-lang
Recommends:     libavcodec
Recommends:     libavformat
Recommends:     libavutil
Recommends:     libmp3lame0
%if %{with mad}
BuildRequires:  pkgconfig(mad)
%endif
%if %{with lame}
BuildRequires:  libmp3lame-devel
%endif
%if %{with twolame}
BuildRequires:  pkgconfig(twolame)
%endif

%description
Audacity is a program that manipulates digital audio wave forms. In
addition to recording sounds directly from within the program, it
imports many sound file formats, including WAV, AIFF, AU, IRCAM,
MP, and Ogg Vorbis. With Audacity, you can edit wave data larger
than the physical memory size of your computer.

%lang_package

%prep
%setup -q -n %{name}-minsrc-%{version}
%patch0
%patch1 -p1
%patch2 -p1
%patch3
%patch5
cp -f %{SOURCE1} LICENSE_NYQUIST.txt
# Make sure we use the system versions.
rm -rf lib-src/{expat,libvamp,libsoxr,ffmpeg}/
%if %{with lame}
rm -rf lib-src/lame/
%endif

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
export CXXFLAGS="$CFLAGS"
aclocal -I m4
autoconf
%configure \
%ifnarch %ix86 x86_64
  --disable-sse                \
%endif
  --docdir=%{_docdir}/%{name}/

make %{?_smp_mflags}

%install
%make_install

# E-mail wrote to feedback@audacityteam.org.
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/48x48/mimetypes/
mv -f %{buildroot}%{_datadir}/pixmaps/gnome-mime-application-x-audacity-project.xpm \
  %{buildroot}%{_datadir}/icons/hicolor/48x48/mimetypes/application-x-audacity-project.xpm
rm -rf %{buildroot}%{_datadir}/pixmaps/
%find_lang %{name}

%post
%desktop_database_post
%icon_theme_cache_post
%mime_database_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%mime_database_postun

%files
%defattr(-,root,root)
%doc LICENSE.txt LICENSE_NYQUIST.txt README.txt
%doc %{_docdir}/%{name}/
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_datadir}/icons/hicolor/*/mimetypes/*%{name}*
%{_datadir}/mime/packages/%{name}.xml
%{_mandir}/man?/%{name}.?%{?ext_man}
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
